version = "0.3"
project_url = "https://github.com/memset/sftpcloudfs"
config_file = "/etc/sftpcloudfs.conf"

